@@ -164,23 +164,27 @@ class AwesomeHTMLTranslator(HTML5Translator):
                 location=node,
                 **highlight_args,
             )
-            if "hl_text" in highlight_args:
-                # this markup follows Google's recommendation
-                # https://developers.google.com/style/placeholders
-                placeholder = highlight_args["hl_text"]
-                highlighted = re.sub(
-                    placeholder,
-                    f"<var>{placeholder}</var>",
-                    highlighted,
-                )
 
-            # Code blocks that don't have a caption are not wrapped inside a <container>
+            # wrap `placeholder` strings with `<var>` elements.
+            # this follows Google's recommendations
+            # https://developers.google.com/style/placeholders
+
+            if "hl_text" in highlight_args:
+                for placeholder in highlight_args["hl_text"].split(","):
+                    placeholder = placeholder.strip()
+                    highlighted = re.sub(
+                        placeholder,
+                        f"<var>{placeholder}</var>",
+                        highlighted,
+                    )
+
+            # Code blocks without captions aren't wrapped inside a <container>
             # node so we add the header here. With captions, see: visit_caption
             if not (
                 isinstance(node.parent, nodes.container)
                 and node.parent.get("literal_block")
             ):
-                self.body.append('<div class="highlight" data-controller="code">\n')
+                self.body.append('<div class="code-wrapper" data-controller="code">\n')
 
                 code_header = "<div class='code-header'>\n"
                 lang_alias = {
@@ -229,7 +233,7 @@ class AwesomeHTMLTranslator(HTML5Translator):
         if node.get("literal_block"):
             # for docutils >0.17
             node.html5tagname = "div"
-            self.body.append('<div class="highlight" data-controller="code">\n')
+            self.body.append('<div class="code-wrapper" data-controller="code">\n')
             lang = node.get("language", "")
             code_header = "<div class='code-header'>\n"
             code_header += (
